Index: /issm/trunk/src/m/classes/public/BasinConstrain.m
===================================================================
--- /issm/trunk/src/m/classes/public/BasinConstrain.m	(revision 1757)
+++ /issm/trunk/src/m/classes/public/BasinConstrain.m	(revision 1758)
@@ -62,4 +62,4 @@
 
 %make sure icefronts that are completely spc'd are taken out:
-free_segments=find(sum(md.spcvelocity(md.segmentonneumann_diag(:,1:2),1:2),2)~=2);
+free_segments=find(sum(md.spcvelocity(md.pressureload(:,1:2),1:2),2)~=2);
 md.pressureload=md.pressureload(free_segments,:);
Index: /issm/trunk/src/m/classes/public/BasinConstrain2.m
===================================================================
--- /issm/trunk/src/m/classes/public/BasinConstrain2.m	(revision 1757)
+++ /issm/trunk/src/m/classes/public/BasinConstrain2.m	(revision 1758)
@@ -63,4 +63,4 @@
 
 %make sure icefronts that are completely spc'd are taken out:
-free_segments=find(sum(md.spcvelocity(md.segmentonneumann_diag(:,1:2),1:2),2)~=2);
+free_segments=find(sum(md.spcvelocity(md.pressureload(:,1:2),1:2),2)~=2);
 md.pressureload=md.pressureload(free_segments,:);
Index: /issm/trunk/src/m/classes/public/BasinConstrainShelf.m
===================================================================
--- /issm/trunk/src/m/classes/public/BasinConstrainShelf.m	(revision 1757)
+++ /issm/trunk/src/m/classes/public/BasinConstrainShelf.m	(revision 1758)
@@ -76,4 +76,4 @@
 
 %make sure icefronts that are completely spc'd are taken out:
-free_segments=find(sum(md.spcvelocity(md.segmentonneumann_diag(:,1:2),1:2),2)~=2);
+free_segments=find(sum(md.spcvelocity(md.pressureload(:,1:2),1:2),2)~=2);
 md.pressureload=md.pressureload(free_segments,:);
Index: /issm/trunk/src/m/classes/public/display/displayprognostic.m
===================================================================
--- /issm/trunk/src/m/classes/public/display/displayprognostic.m	(revision 1757)
+++ /issm/trunk/src/m/classes/public/display/displayprognostic.m	(revision 1758)
@@ -18,4 +18,2 @@
 disp(sprintf('\n      boundary conditions:'));
 fielddisplay(md,'spcthickness','constraints flag list (first column) and values (second column)');
-fielddisplay(md,'segmentonneumann_prog','segments on ice front list');
-fielddisplay(md,'neumannvalues_prog','values of the Neumann [m/a]');
Index: /issm/trunk/src/m/classes/public/geography2.m
===================================================================
--- /issm/trunk/src/m/classes/public/geography2.m	(revision 1757)
+++ /issm/trunk/src/m/classes/public/geography2.m	(revision 1758)
@@ -148,5 +148,5 @@
 md.elementonicesheet=elementonicesheet;
 
-md.segmentonneumann_diag=segments;
+md.pressureload=segments;
 md.counter=2;
 md.segmentmarkers(:)=1;
Index: /issm/trunk/src/m/classes/public/plot/plot_manager.m
===================================================================
--- /issm/trunk/src/m/classes/public/plot/plot_manager.m	(revision 1757)
+++ /issm/trunk/src/m/classes/public/plot/plot_manager.m	(revision 1758)
@@ -72,6 +72,6 @@
 			plot_sarpwr(md,options_structure,width,i)
 			return
-		case {'segmentonneumann_diag','segmentonneumann_prog'}
-			plot_segmentonneumann(md,options_structure,width,i,data)
+		case 'pressureload'
+			plot_pressureload(md,options_structure,width,i,data)
 			return
 		case 'segments'
Index: /issm/trunk/src/m/classes/public/plot/plot_pressureload.m
===================================================================
--- /issm/trunk/src/m/classes/public/plot/plot_pressureload.m	(revision 1758)
+++ /issm/trunk/src/m/classes/public/plot/plot_pressureload.m	(revision 1758)
@@ -0,0 +1,83 @@
+function plot_pressureload(md,options_structure,width,i,data);
+%PLOT_PRESSURELOAD - plot segment on neumann BC
+%
+%   Usage:
+%      plot_pressureload(md,options_structure,width,i);
+%
+%   See also: PLOTMODEL
+
+%plot mesh boundaries
+subplot(width,width,i); 
+
+%process mesh and data
+[x y z elements is2d]=processmesh(md,options_structure);
+pressureload=md.pressureload;
+
+if strcmpi(md.type,'2d'),
+
+	%plot mesh
+	A=elements(:,1); B=elements(:,2); C=elements(:,3); 
+	h1=patch( 'Faces', [A B C], 'Vertices', [x y z],'FaceVertexCData', [1 1 1],'FaceColor','none','EdgeColor','black');
+	hold on;
+
+	%highlight elements on neumann in Green
+	pos=pressureload(:,end);
+	A=elements(pos,1); B=elements(pos,2); C=elements(pos,3); 
+	h2=patch( 'Faces', [A B C], 'Vertices', [x y z],'FaceVertexCData', [1 1 1],'FaceColor','green','EdgeColor','black');
+	hold on;
+
+	%display arrows pointing outward
+	xstart=mean(x(pressureload(:,1:end-1)),2);
+	ystart=mean(y(pressureload(:,1:end-1)),2);
+	length=sqrt((x(pressureload(:,1))-x(pressureload(:,2))).^2 + (y(pressureload(:,1))-y(pressureload(:,2))).^2 );
+	normal(:,1)=cos(atan2((x(pressureload(:,1))-x(pressureload(:,2))) , (y(pressureload(:,2))-y(pressureload(:,1)))));
+	normal(:,2)=sin(atan2((x(pressureload(:,1))-x(pressureload(:,2))) , (y(pressureload(:,2))-y(pressureload(:,1)))));
+	xend=xstart+length.*normal(:,1);
+	yend=ystart+length.*normal(:,2);
+	q=quiver(xstart,ystart,xend-xstart,yend-ystart); hold on;
+	h3=plot(xstart,ystart,'r*');
+else
+
+	%plot mesh
+	A=elements(:,1); B=elements(:,2); C=elements(:,3); D=elements(:,4); E=elements(:,5); F=elements(:,6);
+	h1=patch( 'Faces', [A B C], 'Vertices', [x y z],'FaceVertexCData', [1 1 1],'FaceColor','none','EdgeColor','black');
+	patch( 'Faces', [D E F], 'Vertices', [x y z],'FaceVertexCData', [1 1 1],'FaceColor','none','EdgeColor','black');
+	patch( 'Faces', [A B E D], 'Vertices', [x y z],'FaceVertexCData', [1 1 1],'FaceColor','none','EdgeColor','black');
+	patch( 'Faces', [B E F C ], 'Vertices', [x y z],'FaceVertexCData', [1 1 1],'FaceColor','none','EdgeColor','black');
+	patch( 'Faces', [C A D F ], 'Vertices', [x y z],'FaceVertexCData', [1 1 1],'FaceColor','none','EdgeColor','black');
+	hold on;
+
+	%highlight elements on neumann in Green
+	pos=pressureload(:,end);
+	A=elements(pos,1); B=elements(pos,2); C=elements(pos,3); D=elements(pos,4); E=elements(pos,5); F=elements(pos,6);
+	h2=patch( 'Faces', [A B C], 'Vertices', [x y z],'FaceVertexCData', [1 1 1],'FaceColor','green','EdgeColor','black');
+	patch( 'Faces', [D E F], 'Vertices', [x y z],'FaceVertexCData', [1 1 1],'FaceColor','green','EdgeColor','black');
+	patch( 'Faces', [A B E D], 'Vertices', [x y z],'FaceVertexCData', [1 1 1],'FaceColor','green','EdgeColor','black');
+	patch( 'Faces', [B E F C ], 'Vertices', [x y z],'FaceVertexCData', [1 1 1],'FaceColor','green','EdgeColor','black');
+	patch( 'Faces', [C A D F ], 'Vertices', [x y z],'FaceVertexCData', [1 1 1],'FaceColor','green','EdgeColor','black');
+	hold on;
+
+	%display arrows pointing outward
+	xstart=mean(x(pressureload(:,1:end-1)),2);
+	ystart=mean(y(pressureload(:,1:end-1)),2);
+	zstart=mean(z(pressureload(:,1:end-1)),2);
+	length=sqrt((x(pressureload(:,1))-x(pressureload(:,2))).^2 + (y(pressureload(:,1))-y(pressureload(:,2))).^2 );
+	normal(:,1)=cos(atan2((x(pressureload(:,1))-x(pressureload(:,2))) , (y(pressureload(:,2))-y(pressureload(:,1)))));
+	normal(:,2)=sin(atan2((x(pressureload(:,1))-x(pressureload(:,2))) , (y(pressureload(:,2))-y(pressureload(:,1)))));
+	xend=xstart+length.*normal(:,1);
+	yend=ystart+length.*normal(:,2);
+	q=quiver3(xstart,ystart,zstart,xend-xstart,yend-ystart,0); hold on;
+	h3=plot3(xstart,ystart,zstart,'r*');
+end
+
+%legend
+legend([h2,q],'element on ice front','normal vectors')
+
+%apply options
+if isnan(options_structure.title)
+	options_structure.title='Neumann boundary conditions';
+end 
+if isnan(options_structure.colorbar)
+	options_structure.colorbar=0;
+end
+applyoptions(md,[],options_structure);
Index: sm/trunk/src/m/classes/public/plot/plot_segmentonneumann.m
===================================================================
--- /issm/trunk/src/m/classes/public/plot/plot_segmentonneumann.m	(revision 1757)
+++ 	(revision )
@@ -1,84 +1,0 @@
-function plot_segmentonneumann(md,options_structure,width,i,data);
-%PLOT_SEGMENTONNEUMANN - plot segment on neumann BC
-%
-%   Usage:
-%      plot_segmentonneumann(md,options_structure,width,i);
-%
-%   See also: PLOTMODEL
-
-%plot mesh boundaries
-subplot(width,width,i); 
-
-%process mesh and data
-[x y z elements is2d]=processmesh(md,options_structure);
-if strcmp(data,'segmentonneumann_diag') segmentonneumann=md.segmentonneumann_diag;end
-if strcmp(data,'segmentonneumann_prog') segmentonneumann=md.segmentonneumann_prog;end
-
-if strcmpi(md.type,'2d'),
-
-	%plot mesh
-	A=elements(:,1); B=elements(:,2); C=elements(:,3); 
-	h1=patch( 'Faces', [A B C], 'Vertices', [x y z],'FaceVertexCData', [1 1 1],'FaceColor','none','EdgeColor','black');
-	hold on;
-
-	%highlight elements on neumann in Green
-	pos=segmentonneumann(:,end);
-	A=elements(pos,1); B=elements(pos,2); C=elements(pos,3); 
-	h2=patch( 'Faces', [A B C], 'Vertices', [x y z],'FaceVertexCData', [1 1 1],'FaceColor','green','EdgeColor','black');
-	hold on;
-
-	%display arrows pointing outward
-	xstart=mean(x(segmentonneumann(:,1:end-1)),2);
-	ystart=mean(y(segmentonneumann(:,1:end-1)),2);
-	length=sqrt((x(segmentonneumann(:,1))-x(segmentonneumann(:,2))).^2 + (y(segmentonneumann(:,1))-y(segmentonneumann(:,2))).^2 );
-	normal(:,1)=cos(atan2((x(segmentonneumann(:,1))-x(segmentonneumann(:,2))) , (y(segmentonneumann(:,2))-y(segmentonneumann(:,1)))));
-	normal(:,2)=sin(atan2((x(segmentonneumann(:,1))-x(segmentonneumann(:,2))) , (y(segmentonneumann(:,2))-y(segmentonneumann(:,1)))));
-	xend=xstart+length.*normal(:,1);
-	yend=ystart+length.*normal(:,2);
-	q=quiver(xstart,ystart,xend-xstart,yend-ystart); hold on;
-	h3=plot(xstart,ystart,'r*');
-else
-
-	%plot mesh
-	A=elements(:,1); B=elements(:,2); C=elements(:,3); D=elements(:,4); E=elements(:,5); F=elements(:,6);
-	h1=patch( 'Faces', [A B C], 'Vertices', [x y z],'FaceVertexCData', [1 1 1],'FaceColor','none','EdgeColor','black');
-	patch( 'Faces', [D E F], 'Vertices', [x y z],'FaceVertexCData', [1 1 1],'FaceColor','none','EdgeColor','black');
-	patch( 'Faces', [A B E D], 'Vertices', [x y z],'FaceVertexCData', [1 1 1],'FaceColor','none','EdgeColor','black');
-	patch( 'Faces', [B E F C ], 'Vertices', [x y z],'FaceVertexCData', [1 1 1],'FaceColor','none','EdgeColor','black');
-	patch( 'Faces', [C A D F ], 'Vertices', [x y z],'FaceVertexCData', [1 1 1],'FaceColor','none','EdgeColor','black');
-	hold on;
-
-	%highlight elements on neumann in Green
-	pos=segmentonneumann(:,end);
-	A=elements(pos,1); B=elements(pos,2); C=elements(pos,3); D=elements(pos,4); E=elements(pos,5); F=elements(pos,6);
-	h2=patch( 'Faces', [A B C], 'Vertices', [x y z],'FaceVertexCData', [1 1 1],'FaceColor','green','EdgeColor','black');
-	patch( 'Faces', [D E F], 'Vertices', [x y z],'FaceVertexCData', [1 1 1],'FaceColor','green','EdgeColor','black');
-	patch( 'Faces', [A B E D], 'Vertices', [x y z],'FaceVertexCData', [1 1 1],'FaceColor','green','EdgeColor','black');
-	patch( 'Faces', [B E F C ], 'Vertices', [x y z],'FaceVertexCData', [1 1 1],'FaceColor','green','EdgeColor','black');
-	patch( 'Faces', [C A D F ], 'Vertices', [x y z],'FaceVertexCData', [1 1 1],'FaceColor','green','EdgeColor','black');
-	hold on;
-
-	%display arrows pointing outward
-	xstart=mean(x(segmentonneumann(:,1:end-1)),2);
-	ystart=mean(y(segmentonneumann(:,1:end-1)),2);
-	zstart=mean(z(segmentonneumann(:,1:end-1)),2);
-	length=sqrt((x(segmentonneumann(:,1))-x(segmentonneumann(:,2))).^2 + (y(segmentonneumann(:,1))-y(segmentonneumann(:,2))).^2 );
-	normal(:,1)=cos(atan2((x(segmentonneumann(:,1))-x(segmentonneumann(:,2))) , (y(segmentonneumann(:,2))-y(segmentonneumann(:,1)))));
-	normal(:,2)=sin(atan2((x(segmentonneumann(:,1))-x(segmentonneumann(:,2))) , (y(segmentonneumann(:,2))-y(segmentonneumann(:,1)))));
-	xend=xstart+length.*normal(:,1);
-	yend=ystart+length.*normal(:,2);
-	q=quiver3(xstart,ystart,zstart,xend-xstart,yend-ystart,0); hold on;
-	h3=plot3(xstart,ystart,zstart,'r*');
-end
-
-%legend
-legend([h2,q],'element on ice front','normal vectors')
-
-%apply options
-if isnan(options_structure.title)
-	options_structure.title='Neumann boundary conditions';
-end 
-if isnan(options_structure.colorbar)
-	options_structure.colorbar=0;
-end
-applyoptions(md,[],options_structure);

Index: /issm/trunk/src/m/classes/public/modelzoom.m
===================================================================
--- /issm/trunk/src/m/classes/public/modelzoom.m	(revision 1757)
+++ /issm/trunk/src/m/classes/public/modelzoom.m	(revision 1758)
@@ -32,9 +32,9 @@
 elementlist=find( (xel>xlim0(1)) & (xel<xlim0(2)) & (yel>ylim0(1)) & (yel<ylim0(2)) );
 
-%Create a list of elements locations from the input model, which are on the segmentonneumann_diag: 
-if(~isempty(md.segmentonneumann_diag)),
-	xelneumann=(md.x(md.elements(md.segmentonneumann_diag(:,3),1))+md.x(md.elements(md.segmentonneumann_diag(:,3),2))+md.x(md.elements(md.segmentonneumann_diag(:,3),3)))/3;
-	yelneumann=(md.y(md.elements(md.segmentonneumann_diag(:,3),1))+md.y(md.elements(md.segmentonneumann_diag(:,3),2))+md.y(md.elements(md.segmentonneumann_diag(:,3),3)))/3;
-	%Figure out which elements are within the area, and on segmentonneumann_diag: 
+%Create a list of elements locations from the input model, which are on the pressureload: 
+if(~isempty(md.pressureload)),
+	xelneumann=(md.x(md.elements(md.pressureload(:,3),1))+md.x(md.elements(md.pressureload(:,3),2))+md.x(md.elements(md.pressureload(:,3),3)))/3;
+	yelneumann=(md.y(md.elements(md.pressureload(:,3),1))+md.y(md.elements(md.pressureload(:,3),2))+md.y(md.elements(md.pressureload(:,3),3)))/3;
+	%Figure out which elements are within the area, and on pressureload: 
 	elementlistneumann=find( (xelneumann>xlim0(1)) & (xelneumann<xlim0(2)) & (yelneumann>ylim0(1)) & (yelneumann<ylim0(2)) );
 end
@@ -95,10 +95,10 @@
 end
 
-%Deal with segmentonneumann_diag: 
-if(~isempty(md.segmentonneumann_diag)),
-	md2.segmentonneumann_diag=md.segmentonneumann_diag(elementlistneumann,:);
-	md2.segmentonneumann_diag(:,1)=gridpos(md2.segmentonneumann_diag(:,1));
-	md2.segmentonneumann_diag(:,2)=gridpos(md2.segmentonneumann_diag(:,2));
-	md2.segmentonneumann_diag(:,3)=elempos(md2.segmentonneumann_diag(:,3));
+%Deal with pressureload: 
+if(~isempty(md.pressureload)),
+	md2.pressureload=md.pressureload(elementlistneumann,:);
+	md2.pressureload(:,1)=gridpos(md2.pressureload(:,1));
+	md2.pressureload(:,2)=gridpos(md2.pressureload(:,2));
+	md2.pressureload(:,3)=elempos(md2.pressureload(:,3));
 end
 